bcov <-function(object,nsim=500,itmax=500,verbose=FALSE,data.name=NULL)
{
# Function bcov (bootstrap covariance) to create a
# version of the covariance matrix of the parameters of a hidden
# generalized linear Markov model through  parametric bootstrapping.

# Put together a data name tag for the output.
if(is.null(data.name)) data.name <- object$data.name

# Keep the kontrasts konsistent.
contr  <- object$contrasts
oldc   <- options(contr)
on.exit(options(oldc))

fmla   <- object$formula
cells  <- object$cells
mixt   <- object$mixture
meth   <- object$method
tol    <- object$tolerance
par0   <- list(tpm=object$params$tpm,phi=object$params$phi)

miss.frac <- object$miss.frac
rslt      <- list()
i         <- 0
nc.count  <- 0
repeat{
	dat.sim <- rhglmm(object,miss.frac=miss.frac,set.con=FALSE)
	p <- hglmm(fmla,data=dat.sim,cells=cells,par0=par0,mixture=mixt,
                   method=meth,tolerance=tol,itmax=itmax)
	if(p$converged) {
		i <- i+1
		rslt[[i]] <- p$theta
		if(verbose) cat(i,'\n')
	}
	else nc.count <- nc.count+1
	if(i>=nsim) break
}

# Put things together and return.
m <- matrix(unlist(rslt),byrow=TRUE,ncol=length(rslt[[1]]))
C.hat <- var(m)
list(C.hat=C.hat,nc.count=nc.count,data.name=data.name)
}
