get.gl <- function(theta,K,X,y,cf) {
#
# Function get.gl --- get gradient and log likelihood.
#
npar <- length(theta)
npro <- K*(K-1)
nphi <- npar-npro
rho  <- theta[1:npro]
tpm  <- fix.tpm(rho,K,TRUE)
ispd <- revise.ispd(tpm)
phi  <- theta[-(1:npro)]
lam  <- exp(X%*%phi)
fy   <- dpois(y,lam)
fy[is.na(fy)] <- 1
dp   <- derivp(npar,K,rho,TRUE)
d1p  <- dp$d1p
dpi  <- derivpi(ispd,tpm,npar,dp)
d1pi <- dpi$d1pi
ncf  <- table(cf)
nc   <- length(ncf)
lcf  <- as.character(cf[cumsum(ncf)])

# Run through the cells:
alist  <- list()
xllist <- list()
filist <- list()
for(xl in lcf) {
	ind   <- (cf==xl)
	dmat  <- X[ind,]
        nind  <- nrow(dmat)
	fyxl  <- matrix(fy[ind],nrow=K)
	lamxl <- matrix(lam[ind],nrow=K)
	yxl   <- matrix(y[ind],ncol=K,byrow=TRUE)[,1] # All columns identical.
	ymiss <- is.na(yxl)
	ny    <- length(yxl)

	xxx   <- .Fortran(
		"getgl",
		NAOK=TRUE,
		fy=as.double(fyxl),
		xlam=as.double(lamxl),
		y=as.double(yxl),
		ymiss=as.integer(ymiss),
		dmat=as.double(t(dmat)),
                nind=as.integer(nind),
		tpm=as.double(tpm),
		xispd=as.double(ispd),
		d1pi=as.double(d1pi),
		kstate=as.integer(K),
		n=as.integer(ny),
		nphi=as.integer(nphi),
		npar=as.integer(npar),
		d1p=as.double(d1p),
		d1f=double(K*npar),
		alpha=double(K),
		alphw=double(K),
		a=double(K*npar),
		aw=double(K*npar),
		xlc=double(ny),
		PACKAGE="hglmm"
		)
	xlc <- xxx$xlc
	alist[[xl]]  <- matrix(xxx$a,K,npar)/xlc[ny]
	xllist[[xl]] <- sum(log(xlc))
} 
a     <- array(unlist(alist),c(K,npar,nc))
grad  <- apply(a,2,sum)
ll    <- sum(unlist(xllist))
list(ll=ll,grad=grad)
}
