hglmm.bf <- function(formula,data,K,theta,mixture=FALSE,
                         itmax=200,tolerance=NULL,overpar=FALSE,
                         digits=NULL,verbose=FALSE) {
#
# Function hglmm.bf.  The engine to carry out the fitting of a
# Hidden Markov model using the brute force method.
#

if(mixture)
	stop(paste("Sorry; can't do mixtures by the",
                   "brute force method yet.\n"))

# Do some initial housekeeping.
fmla <- formula
npar <- length(theta)
npro <- K*(K-1)
X    <- model.matrix(fmla[-2],data)
y    <- data[,as.character(fmla)[2]]
cf   <- data$cf
nll  <- function(theta,K,X,y,cf) {
	-get.l(theta,K,X,y,cf) 
}

# Set the control.
ctrl <- if(verbose) list(trace=6,maxit=itmax) else list(maxit=itmax)
if(!is.null(tolerance)) ctrl <- c(ctrl,list(reltol=tolerance))

# Do it to it.
rslt   <- optim(theta,nll,method="BFGS",hessian=TRUE,control=ctrl,
                K=K,X=X,y=y,cf=cf)

theta <- rslt$par
mf    <- sum(is.na(data$y))/nrow(data)
hess  <- -rslt$hessian
grad  <- get.gl(theta,K,X,y,cf)$grad
ll    <- -rslt$value
cnts  <- rslt$counts
conv  <- rslt$convergence==0
phi   <- theta[-(1:npro)]
rho   <- theta[1:npro]
tpm   <- fix.tpm(rho,K,TRUE)
ispd  <- revise.ispd(tpm)
lam   <- exp(X%*%phi)
fy    <- dpois(y,lam)
fy[is.na(fy)] <- 1
nms   <- dimnames(X)[[2]]
nms[nms=="(Intercept)"] <- "mu"
names(phi) <- nms

if(overpar) {
# Do a bit of cosmetix:  Arrange to get the overparameterized
# version of the model.
	epsilon       <- .Machine$double.eps
	data$weights  <- as.vector(recurse(fy,tpm,cf,epsilon,mixture=FALSE)$gamma)
	rrr    <- glm(fmla, data=data, weights=weights, family=poisson,
	              na.action=na.omit)
	phi.em <- coef(rrr)
	nms    <- names(phi.em)
	names(phi.em)[nms=='(Intercept)']   <- 'mu'
	names(rrr$coef)[nms=='(Intercept)'] <- 'mu'
	if(!identical(all.equal(phi,phi.em),TRUE)) {
		warning("EM step changed the model parameters.\n")
		phi.over.em <- dummy.coef(rrr)
		rrr$coef <- phi
	} else {
		phi.em <- NULL
		phi.over.em <- NULL
	}
	phi.over <- dummy.coef(rrr)
	nms      <- names(phi.over)
	names(phi.over)[nms=='(Intercept)']   <- 'mu'
} else {
	phi.over <- NULL
	phi.em   <- NULL
}

theta <- c(rho,phi)

names(theta)[1:(K*(K-1))] <-
      paste('rho_',t(row(tpm)[,-K]),t(col(tpm)[,-K]),sep='')
par <- list(tpm=tpm,ispd=ispd,phi=phi,phi.over=phi.over)
if(!is.null(phi.em)) {
	par$phi.em <- phi.em
	par$phi.over.em <- phi.over.em
}
data$weights <- NULL
rownames(hess) <- colnames(hess) <- names(theta)
names(grad) <- names(theta)

list(params=par,theta=theta,hessian=hess,grad=grad,log.like=ll,
     converged=conv,counts=cnts,mixture=mixture,
     expo=TRUE,formula=fmla,contrasts=options("contrasts"),
     miss.frac=mf,lambda=lam,fy=fy,data=data)
}
