hglmm.nl <- function (formula, data, K, theta, mixture = FALSE, 
    itmax = 200, tolerance = NULL, overpar = FALSE, use.anal=FALSE,
    ca=FALSE, verbose = FALSE) 
{
    if (mixture) 
        stop(paste("Sorry; can't do mixtures by the",
                   "brute force method yet.\n"))
    fmla <- formula
    npar <- length(theta)
    npro <- K * (K - 1)
    X <- model.matrix(fmla[-2], data)
    y <- data[, as.character(fmla)[2]]
    cf <- data$cf
    foo <- if(use.anal) function (theta, K, X, y, cf) {
    xxx <- get.hgl(theta,K,X,y,cf)
    rslt <- -xxx$ll
	attr(rslt,'gradient') <- -xxx$grad
	attr(rslt,'hessian')  <- -xxx$hess
	rslt
    } else function(theta,K,X,y,cf){-get.l(theta,K,X,y,cf)}
    if(!is.null(tolerance)) tolerance=sqrt(.Machine$double.eps)
    print.level <- if(verbose) 2 else 0
    rslt <- suppressWarnings(nlm(foo,theta, hessian = TRUE,
            print.level=print.level,gradtol=tolerance,iterlim=itmax,
            check.analyticals=ca,K = K, X = X, y = y, cf = cf))
    theta <- rslt$estimate
    mf <- sum(is.na(data$y))/nrow(data)
    hess <- -rslt$hessian
    grad <- -rslt$gradient
    ll <- -rslt$minimum
    nstep <- rslt$iterations
    conv <- rslt$code <= 2
    phi <- theta[-(1:npro)]
    rho <- theta[1:npro]
    tpm <- fix.tpm(rho, K, TRUE)
    ispd <- revise.ispd(tpm)
    lam <- exp(X %*% phi)
    fy <- dpois(y, lam)
    fy[is.na(fy)] <- 1
    nms <- dimnames(X)[[2]]
    nms[nms == "(Intercept)"] <- "mu"
    names(phi) <- nms
    if (overpar) {
        epsilon <- .Machine$double.eps
        data$weights <- c(recurse(fy, tpm, cf, epsilon, mixture = FALSE)$gamma)
        rrr <- glm(fmla, data = data, weights = weights, family = poisson, 
            na.action = na.omit)
        phi.em <- coef(rrr)
        nms <- names(phi.em)
        names(phi.em)[nms == "(Intercept)"] <- "mu"
        names(rrr$coef)[nms == "(Intercept)"] <- "mu"
        if (!identical(all.equal(phi, phi.em), TRUE)) {
            warning("EM step changed the model parameters.\n")
            phi.over.em <- dummy.coef(rrr)
            rrr$coef <- phi
        }
        else {
            phi.em <- NULL
            phi.over.em <- NULL
        }
        phi.over <- dummy.coef(rrr)
        nms <- names(phi.over)
        names(phi.over)[nms == "(Intercept)"] <- "mu"
    }
    else {
        phi.over <- NULL
        phi.em <- NULL
    }
    theta <- c(rho, phi)
    names(theta)[1:(K * (K - 1))] <- paste("rho_",t(row(tpm)[,-K]),
                                           t(col(tpm)[,-K]),sep = "")
    par <- list(tpm = tpm, ispd = ispd, phi = phi, phi.over = phi.over)
    if (!is.null(phi.em)) {
        par$phi.em <- phi.em
        par$phi.over.em <- phi.over.em
    }
    data$weights <- NULL
    rownames(hess) <- colnames(hess) <- names(theta)
    names(grad) <- names(theta)

    list(params = par, theta = theta, hessian = hess, gradient=grad,
        log.like = ll,converged = conv, nstep = nstep, mixture = mixture,
        expo = TRUE, formula = fmla, contrasts = options("contrasts"),
        miss.frac = mf, lambda = lam, fy = fy, data = data)
}
