init.all <- function(formula,data,K=NULL,par0=NULL,mixture=FALSE,
                     breaks=NULL,expo=FALSE) {
#
# Function init.all.  To initialize all of the parameters, i.e. the
# transition probability matrix and the generalized linear model
# parameters.
#

fmla <- formula
tpm <- par0$tpm
phi <- par0$phi
if(is.null(K)) {
	if(is.null(par0))
		stop("At least one of K and par0 must be specified.\n")
	K <- nrow(tpm)
} else {
	if(!is.null(tpm) && K!=nrow(tpm))
		stop("The values of K and par0$tpm are incompatible.\n")
}

if(is.null(tpm) | is.null(phi)) {
	lcf <- levels(data$cf)
	ynm <- as.character(fmla)[2]
	y   <- data[,ynm]
	if(length(unique(y[!is.na(y)]))<K)
   		stop(paste("Cannot possibly fit a K state chain to",
                           "fewer than K unique values.\n"))
	if(is.null(breaks)) breaks <- breaker(y,K)
	state <- rep(NA,nrow(data))
	stmp  <- list()
	for(xl in lcf) {
		ind  <- (data$cf==xl)
		temp <- y[ind]
		state[ind] <- as.numeric(cut(temp,breaks))
		stmp[[xl]] <- c(state[ind],-1)
	}
	stmp <- unlist(stmp)
}
if(is.null(tpm)) tpm <- est.tpm(stmp,K,mixture)
if(expo) {
	A   <- tpm[,1:(K-1)]/tpm[,K]
	rho <- c(t(log(A)))
}

if(is.null(phi)) {
	data$state <- factor(state)
	rslt <- glm(fmla,data=data,family=poisson,na.action=na.omit)
	phi  <- coef(rslt)
}
if(expo) list(rho=rho,phi=phi) else list(tpm=tpm,phi=phi)
}
