plot.hglmm <- local({

rbox <- function() {
    if(is.null(dev.list()))
        stop("No device open.\n")
    uuu <- par()$usr
    lines(c(uuu[1],uuu[1]),c(0,uuu[4]),lwd=2)
    lines(c(uuu[1],uuu[2]),c(uuu[4],uuu[4]),lwd=2)
    lines(c(uuu[2],uuu[2]),c(0,uuu[4]),lwd=2)
    lines(c(uuu[1],uuu[2]),c(0,0),lwd=1)
    invisible()
}

function(x,...,wcells=NULL,col="red",nrnc=NULL,ntop=NULL,
         xlab=NULL,ylab=NULL,xlim=NULL,ylim=NULL,main=NULL,
         cex.main=1.5) {
if(is.null(xlab)) xlab <- "x"
if(is.null(ylab)) ylab <- "probability"
K <- nrow(x$params$tpm)
if(is.null(wcells)) {
    wcells <- levels(x$data$cf)
}
if(!is.null(main)) main <- rep(main,length=length(wcells))
if(is.null(nrnc)) {
    nr <- ceiling(sqrt(K))
    nc <- ceiling(K/nr)
    nrnc <- c(nr,nc)
} else {
    if(nrnc[1]*nrnc[2] < K)
       stop("Specified dimensions for the array of plots is too small.\n")
}
OP <- par(mfrow=nrnc,oma=c(0,0,3,0))
on.exit(par(OP))
nwc   <- length(wcells)
lambs <- vector("list",nwc)
devint <- dev.interactive() | (interactive() & is.null(dev.list()))
for(i in 1:nwc) {
    lcf <- wcells[i]
    X <- unique(with(x,model.matrix(formula[-2],data=data[data$cf==lcf,])))
    if(nrow(X) != K) {
        whinge <- paste0("For cell ",lcf," the number of unique rows of the\n",
                         "  design matrix is not equal to the number of\n",
                         "  states.  Alles upgefucken ist.\n")
        stop(whinge)
    }
    rownames(X) <- paste0("state",1:K)
    lambs[[i]] <- exp(X%*%x$params$phi)
}
if(is.null(ntop)) {
    lam <- unlist(lambs)
    ntop <- max(sapply(lam,function(x){qpois(1e-7,x,lower.tail=FALSE)}))
}
xi <- 0:ntop
if(is.null(xlim)) {
    xlim <- c(0,ntop)
} else {
   xi <- xi[xlim[1] <= xi & xi <= xlim[2]]
}
if(is.null(ylim)) {
    p <- vector("list",K*nwc)
    ik <- 0
    for(i in 1:nwc) {
        for(k in 1:K) {
            ik     <- ik+1
            p[[ik]] <- dpois(xi,lambs[[i]][k])
        }
    }
    ylim <- c(0,max(unlist(p)))
} else p <- NULL
ik <- 0
for(i in 1:nwc) {
    for(k in 1:K) {
        ik <- ik+1
        pk <- if(is.null(p)) dpois(xi,lambs[[i]][k]) else p[[ik]]
        plot(xi,pk,type="h",xlim=xlim,ylim=ylim,main=paste0("state ",k),
             col=col,xlab=xlab,ylab=ylab,axes=FALSE)
        axis(side=2,lwd=0,lwd.ticks=1)
        axis(side=1,lwd=0,pos=0)
        rbox()
    }
    if(is.null(main)) {
        mane <- paste0("Cell ",lcf)
    } else {
        mane <- main[i]
    }
    if(mane!="") mtext(side=3,outer=TRUE,text=mane,cex=cex.main)
    if(devint & i < nwc) readline("Go? ")
}
}
})
