recurse <- function(fy,tpm,cf,epsilon,mixture=FALSE) {
#
# Function recurse (nude virgin) to revise the ``recursive probabilities'',
# given the parameters theta, and the observations y.
#

# Get the initial state probability distribution.
ispd <- revise.ispd(tpm)

# Set a bunch of constants:
K   <- nrow(tpm)
k2  <- K*K
ncf <- table(cf)
lcf <- as.character(cf[cumsum(ncf)])
nt  <- length(cf)/K
nx  <- nt-length(lcf)

# Recursive probabilities:
llc   <- list()
gamma <- list()
xi    <- list()
for(xl in lcf) {
	ind <- (cf==xl)
	xfy <- fy[ind]
	N1  <- length(xfy)
        nc  <- N1/K
        N2  <- k2*(nc-1)
        sto <- .Fortran(
                'recurse',
		xfy=as.double(xfy),
                xispd=as.double(ispd),
                tpm=as.double(tpm),
                epsilon=as.double(epsilon),
                kstate=as.integer(K),
		nc=as.integer(nc),
                wrk=double(k2),
                xlc=double(nc),
                alpha=double(N1),
                beta=double(N1),
                gamma=double(N1),
                xi=double(N2),
		PACKAGE="hglmm"
        )

	llc[[xl]]   <- sto$xlc
	gamma[[xl]] <- sto$gamma
	xi[[xl]]  <- sto$xi
}
llc   <- unlist(llc)
gamma <- matrix(unlist(gamma),nrow=K,ncol=nt)
xi    <- array(unlist(xi),dim=c(K,K,nx))
tpm   <- revise.tpm(xi,mixture)

list(gamma=gamma,xi=xi,tpm=tpm,llc=llc)
}
