rhglmm.default <-function(object,formula,cells,miss.frac=0,contr=NULL,...) {
#
# Function rhglmm (r for random) to simulate data from a hidden
# generalized linear Markov model.
#

# Make sure that the kontrasts are konsistent.  The interpretation
# of the coefficients of the linear predictor contained in object$phi
# depends on the contrasts used.  So the contrasts must be the
# same as what you had in mind when you specified phi!!!
# Set the contrasts:
if(!is.null(contr)) {
	cnames <- c("helmert","treatment","sum")
	there  <- match(contr,cnames)
	if(is.na(there))
		stop(paste("Argument \"contrasts\" must be one of",
                           cnames,".\n",sep=""))
	contr   <- c(paste("contr",contr,sep="."),"contr.poly")
	old.con <- options(contrasts=contr)
	on.exit(options(old.con))
}

tpm  <- object$tpm
phi  <- object$phi
data <- object$data
ispd <- object$ispd
if(is.null(ispd)) ispd <- revise.ispd(tpm)

# Build the ``cells'' factor.
data[,"cf"] <- interaction(data[,cells])

# Build the replicated data frame.
K    <- nrow(tpm)
M    <- nrow(data)
data <- as.data.frame(lapply(data,function(x,K,M){rep(x,rep(K,M))},K=K,M=M))
data$state <- factor(rep(1:K,M))

sim.mlt(formula,data,ispd,tpm,phi,miss.frac)
}
