\name{bcov}
\alias{bcov}
\title{ Bootstrap covariance. }
\description{
  Creates an estimate of the covariance matrix of the parameter
  estimates for a hidden generalized linear Markov model via
  parametric bootstrapping.
}
\usage{
   bcov(object, nsim = 500, itmax = 500, verbose = FALSE,
        data.name = NULL)
}
\arguments{
  \item{object}{ An object of class \code{hglmm} as produced by
  \code{\link{hglmm}()}. }
  \item{nsim}{ The number of data sets to simulate, from which
  to estimate parameters.  From each data set a vector of parameters
  is estimated; the estimated covariance matrix is the empirical
  covariance matrix of these \code{nsim} vectors.}
  \item{itmax}{ The maximum number of iterations to be used in attempting
  to achieve convergence when fitting models to the simulated data sets.
  Note that if convergence is not achieved, the simulated data set being
  used is discarded (i.e. it ``doesn't count'') and a replacement data set
  is simulated. }
  \item{verbose}{ Logical scalar.  Should a progress report be printed
  out at each step of the fitting procedure?  (Probably \emph{not},
  if the fitted procedure is to be undertaken 500 times.) }
  \item{data.name}{ An identifying name to be included in the returned
  value.  Defaults to \code{object$data.name}. }
}
\details{
  Although this documentation refers to ``generalized linear
  models'', currently only log linear Poisson models are provided
  for.  More flexibility may be added at a future date.
}
\value{
  A list with components:
  \item{C.hat}{The parametric bootstrap estimate of the covariance
  matrix of the parameter estimates.}
  \item{nc.count}{A count of the total number of times that the
  algorithm failed to converge during the bootstrapping procedure.}
  \item{data.name}{An identifying name, perhaps specifying the
  data set to which the model was fitted so as to produce
  \code{object}.}
}
\references{
  See the help for \code{\link{hglmm}()} for references.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}
\seealso{ \code{\link{fitted.hglmm}()} \code{\link{rhglmm}()}
          \code{\link{rhglmm.default}()} \code{\link{rhglmm.hglmm}()} }
\examples{
    \dontrun{
        loc4 <- c("LngRf","BondiE","BondiOff","MlbrOff")
        SCC4 <- SydColCount[SydColCount$locn \%in\% loc4,] 
        SCC4$locn <- factor(SCC4$locn) # Get rid of unused levels.
        rownames(SCC4) <- 1:nrow(SCC4)
        fit <- hglmm(y~locn+depth,SCC4,c("locn","depth"),K=2,
                     contr="sum",verb=TRUE)
	cvr <- bcov(fit,nsim=500)
    }
}
\keyword{ models }
