\name{fitted.hglmm}
\alias{fitted.hglmm}
\title{ Predict method for hidden generalized linear Markov models. }
\description{
  Predicted values based on hidden generalized linear Markov model
  object. }
\usage{
\method{fitted}{hglmm}(object, ...)
}
\arguments{
  \item{object}{ An object of class \code{hglmm} as returned
  by \code{\link{hglmm}()}. }
  \item{\dots}{ Not used. }
}
\details{
  Although this documentation refers to ``generalized linear
  models'', currently only log linear Poisson models are provided
  for.  More flexibility may be added at a future date.
}
\value{
  A vector of fitted values of the same length as that of the
  observed values (i.e. length equal to the row dimension of the
  data frame to which the model was fitted.  This data frame is
  equal to \code{object$data} but with repeated rows corresponding to
  different states collapsed to a single row.  The row dimension of
  this data frame is thus \code{nrow(object$data)/K} where \code{K}
  is the number of states in the model.  This data frame, with
  columns \code{cf} and \code{state} omitted, is returned as an
  attribute \code{data} of the vector of fitted values.
}
\references{
  See the help for \code{\link{hglmm}()} for references.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}
\seealso{ \code{\link{rhglmm}()} \code{\link{rhglmm.default}()}
          \code{\link{rhglmm.hglmm}()} \code{\link{bcov}()} }
\examples{
    loc4 <- c("LngRf","BondiE","BondiOff","MlbrOff")
    SCC4 <- SydColCount[SydColCount$locn \%in\% loc4,] 
    SCC4$locn <- factor(SCC4$locn) # Get rid of unused levels.
    rownames(SCC4) <- 1:nrow(SCC4)
    fit <- hglmm(y~locn+depth,data=SCC4,cells=c("locn","depth"),
                     K=2,contr="sum",verb=TRUE)
    fv  <- fitted(fit)
    with(attr(fv,"data"),plot(y[locn=="BondiOff" & depth=="40"],
             xlab="time",ylab="count"))
    with(attr(fv,"data"),lines(fv[locn=="BondiOff" & depth=="40"]))
}
\keyword{ models }
