\name{reorder.hglmm}
\alias{reorder.hglmm}
\title{
    Reorder the states of a fitted hglmm model
}
\description{
    Reorder the states of a fitted hglmm model so that the
    state effects are in decreasing order.
}
\usage{
\method{reorder}{hglmm}(x, ...)
}
\arguments{
  \item{x}{
  An object of class \code{"hglmm"} as returned by the function
  \code{\link{hglmm}()}.
}
  \item{\dots}{
  Not used.
}
}
\details{
   The states of a fitted hidden Markov model are usually in a
   rather arbitrary order, which can sometimes make it difficult
   to compare different fits.  This function reorders the states
   so that the state corresponding to the largest state effect
   comes first (and so on down the line).
}
\value{
    An object of class \code{"hglmm"} which is identical to
    the argument \code{x} in most respects.  The components
    which differ are:
    \itemize{
    \item \code{params} (the components of this component will,
          or at least may, differ from those of the original)
    \item \code{theta}
    \item \code{hessian}
    \item \code{grad}
    \item \code{lam}
    \item \code{fy}
    }
    The entries of these components (or sub-components) will have the
    same numerical values but will have somewhat different ordering,
    corresponding to the different ordering of the states.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}

\seealso{
    \code{\link{hglmm}()}
}
\examples{
    loc4 <- c("LngRf","BondiE","BondiOff","MlbrOff")
    SCC4 <- SydColCount[SydColCount$locn \%in\% loc4,]
    SCC4$locn <- factor(SCC4$locn) # Get rid of unused levels.
    rownames(SCC4) <- 1:nrow(SCC4)
    fit <- hglmm(y~locn+depth,SCC4,c("locn","depth"),K=2,
                 verb=TRUE)
    ofit <- reorder(fit)
}
