\name{rhglmm.default}
\alias{rhglmm.default}
\title{ Simulate data from a hidden generalized linear Markov
        model.}
\description{
  Takes an object specifying the structure of the data frame in
  which the data are to be stored, and the parameters of the model
  and simulates the data.
}
\usage{
\method{rhglmm}{default}(object,formula,cells, miss.frac = 0,
                         contr = NULL, ...) }
\arguments{
  \item{object}{ An object with components \code{tpm} (the
  transition probability matrix of the hidden Markov chain),
  \code{phi} (the coefficients of the linear predictor of the
  generalized linear model), \code{data} (a data frame determining
  the structure of the simulated data), and \code{ispd} (an optional
  specification of the initial state probability distribution --- if
  this component is not present in \code{object} then it is calculated
  from \code{tpm}).}
  \item{formula}{ The formula specifying the generalized linear model
  to be simulated from.  Note that this formula should include
  \code{state}, a factor specifying the state of the hidden Markov
  chain.  Note also that this formula \emph{must be} compatible
  with the vector \code{phi} of model coefficients provided in
  \code{object}.  It is the user's responsibility to ensure this
  compatibility.}
  \item{cells}{ A character vector specifying the names of the
  factors which determine the ``cells'' of the model. }
  \item{miss.frac}{ Data will be randomly set equal
  to \code{NA} with probability \code{miss.frac}. }
  \item{contr}{ A character string, one of ``treatment'', ``helmert''
  or ``sum'', specifying what contrasts to use in constructing the
  design matrix.  Note that the meaning of the coefficient vector
  \code{phi} depends on the contrasts specified, so make sure
  that the contrasts are the same as what you had in mind when you
  specified phi!!!}
  \item{\dots}{ Not used. }
}
\details{
  Although the name refers to ``generalized linear models'',
  currently only log linear Poisson models are provided for.
  More flexibility may be added at a future date.
}
\value{
  A data frame with the same columns as those of \code{data}
  and also the simulated \emph{response} whose name is determined
  from \code{formula}.
}
\references{
  See the help for \code{\link{hglmm}()} for references.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}
\seealso{  \code{\link{fitted.hglmm}()} \code{\link{rhglmm}()}
           \code{\link{rhglmm.hglmm}()} \code{\link{bcov}()} }
\examples{
  # See the help for rhglmm() for an example.
}
\keyword{ models }
\keyword{ datagen }
