\name{rhglmm.hglmm}
\alias{rhglmm.hglmm}
\title{ Simulate data from a hidden generalized linear Markov
  model which has been fitted to a data set. }
\description{
  Given an object of class \code{hglmm} simulates data from
  the model specified by that object.
}
\usage{
\method{rhglmm}{hglmm}(object, miss.frac = NULL,
                       set.con = TRUE, ...)
}
\arguments{
  \item{object}{ An object of class \code{hglmm} as produced by
  \code{\link{hglmm}()}. }
  \item{miss.frac}{ Data will be randomly set equal
  to \code{NA} with probability \code{miss.frac}. By default its
  value is taken to be the value of \code{object$miss.frac}, so
  if the latter is non-zero and you want \code{miss.frac} to be
  0, you must specify this explicitly.}
  \item{set.con}{ Logical scalar.  Should the contrasts to use
  when building the design matrix be set?  You should probably
  \emph{never} set this to \code{FALSE} yourself.  Note that if
  rhglmm() is called by \code{\link{bcov}()}, then \code{set.con}
  will be set to FALSE, because the setting of the contrasts will
  already have been done by \code{bcov()}.}
  \item{\dots}{ Not used. }
}
\details{
  Although the name refers to ``generalized linear models'',
  currently only log linear Poisson models are provided for.
  More flexibility may be added at a future date.
}
\value{
  A data frame with the same columns as those of \code{object$data}
  but with columns \code{cf} and \code{state} omitted and
  repeated rows corresponding to different states collapsed to
  a single row.  The row dimension of this data frame is thus
  \code{nrow(object$data)/K} where \code{K} is the number of
  states in the model.  The response column is replaced by the
  simulated response.  The name of the response is determined from
  \code{object$formula}.
}
\references{
  See the help for \code{\link{hglmm}()} for references.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}
\seealso{ \code{\link{fitted.hglmm}()} \code{\link{rhglmm}()}
          \code{\link{rhglmm.default}()} \code{\link{bcov}()} }
\examples{
    loc4 <- c("LngRf","BondiE","BondiOff","MlbrOff")
    SCC4 <- SydColCount[SydColCount$locn \%in\% loc4,] 
    SCC4$locn <- factor(SCC4$locn) # Get rid of unused levels.
    rownames(SCC4) <- 1:nrow(SCC4)
    fit <- hglmm(y~locn+depth,SCC4,c("locn","depth"),K=2,
                 contr="sum",verb=TRUE)
    Y   <- rhglmm(fit)
}
\keyword{ models }
\keyword{ datagen }
